@@ -241,22 +241,24 @@ Support install, remove and purge actions."
   (if (and helm-apt-term-buffer
            (buffer-live-p (get-buffer helm-apt-term-buffer)))
       (switch-to-buffer helm-apt-term-buffer)
-    (ansi-term (getenv "SHELL") "term apt")
-    (setq helm-apt-term-buffer (buffer-name)))
-  (term-line-mode)
+      (ansi-term (getenv "SHELL") "term apt")
+      (setq helm-apt-term-buffer (buffer-name))
+      (term-line-mode))
   (let* ((command   (cl-case action
                       (install   "sudo apt-get install ")
                       (reinstall "sudo apt-get install --reinstall ")
                       (uninstall "sudo apt-get remove ")
                       (purge     "sudo apt-get purge ")
                       (t          (error "Unknown action"))))
-         (cands (helm-marked-candidates))
+         (cands     (helm-marked-candidates))
          (cand-list (mapconcat (lambda (x) (format "'%s'" x)) cands " ")))
-    (with-helm-display-marked-candidates "*apt candidates*"
+    (with-helm-display-marked-candidates
+      "*apt candidates*"
       cands
       (when (y-or-n-p (format "%s package(s)" (symbol-name action)))
         (with-current-buffer helm-apt-term-buffer
-          (goto-char (point-max))
+          (goto-char (process-mark (get-buffer-process (current-buffer))))
+          (delete-region (point) (point-max))
           (insert (concat command cand-list))
           (setq helm-external-commands-list nil)
           (setq helm-apt-installed-packages nil)
@@ -290,7 +292,7 @@ With a prefix arg reload cache."
 (provide 'helm-apt)
 
 ;; Local Variables:
-;; byte-compile-warnings: (not cl-functions obsolete)
+;; byte-compile-warnings: (not obsolete)
 ;; coding: utf-8
 ;; indent-tabs-mode: nil
 ;; End:
