@@ -37,7 +37,7 @@
   :group 'helm)
 
 (defcustom helm-boring-buffer-regexp-list
-  '("\\` " "\\*helm" "\\*helm-mode" "\\*Echo Area" "\\*Minibuf")
+  '("\\` " "\\`\\*helm" "\\`\\*Echo Area" "\\`\\*Minibuf")
   "The regexp list that match boring buffers.
 Buffer candidates matching these regular expression will be
 filtered from the list of candidates if the
@@ -224,10 +224,7 @@ Only buffer names are fuzzy matched when this is enabled,
    (migemo :initform 'nomultimatch)
    (volatile :initform t)
    (resume :initform (lambda () (setq helm-buffers-in-project-p nil)))
-   (help-message :initform 'helm-buffer-help-message)
-   (persistent-help
-    :initform
-    "Show this buffer / C-u \\[helm-execute-persistent-action]: Kill this buffer")))
+   (help-message :initform 'helm-buffer-help-message)))
 
 (defvar helm-source-buffers-list nil)
 
@@ -916,7 +913,7 @@ displayed with the `file-name-shadow' face if available."
 (provide 'helm-buffers)
 
 ;; Local Variables:
-;; byte-compile-warnings: (not cl-functions obsolete)
+;; byte-compile-warnings: (not obsolete)
 ;; coding: utf-8
 ;; indent-tabs-mode: nil
 ;; End:
