@@ -18,6 +18,7 @@
 ;;; Code:
 (require 'cl-lib)
 (require 'helm)
+(require 'helm-lib)
 (require 'helm-help)
 (require 'helm-types)
 (require 'helm-utils)
@@ -362,7 +363,9 @@ in other window according to the value of `helm-elisp-help-function'."
 (defun helm-elisp-show-help (candidate &optional name)
   "Show full help for the function CANDIDATE.
 Arg NAME specify the name of the top level function
-calling helm generic completion (e.g \"describe-function\")."
+calling helm generic completion (e.g \"describe-function\")
+which allow calling the right function when CANDIDATE symbol
+refers at the same time to variable and a function."
   (helm-elisp--persistent-help
    candidate 'helm-elisp--show-help-1 name))
 
@@ -517,7 +520,7 @@ Filename completion happen if string start after or between a double quote."
     :persistent-action (lambda (candidate)
                          (helm-elisp--persistent-help
                           candidate 'helm-describe-variable))
-    :persistent-help "Describe variable"
+    :persistent-help "Toggle describe variable"
     :action '(("Describe variable" . helm-describe-variable)
               ("Find variable" . helm-find-variable)
               ("Info lookup" . helm-info-lookup-symbol)
@@ -555,7 +558,7 @@ Filename completion happen if string start after or between a double quote."
     :persistent-action (lambda (candidate)
                          (helm-elisp--persistent-help
                           candidate 'helm-describe-face))
-    :persistent-help "Describe face"
+    :persistent-help "Toggle describe face"
     :action '(("Describe face" . helm-describe-face)
               ("Find face" . helm-find-face-definition)
               ("Customize face" . (lambda (candidate)
@@ -572,7 +575,7 @@ Filename completion happen if string start after or between a double quote."
     :persistent-action (lambda (candidate)
                          (helm-elisp--persistent-help
                           candidate 'helm-describe-function))
-    :persistent-help "Describe command"
+    :persistent-help "Toggle describe command"
     :action '(("Describe function" . helm-describe-function)
               ("Find function" . helm-find-function)
               ("Info lookup" . helm-info-lookup-symbol))))
@@ -592,7 +595,7 @@ Filename completion happen if string start after or between a double quote."
     :persistent-action (lambda (candidate)
                          (helm-elisp--persistent-help
                           candidate 'helm-describe-function))
-    :persistent-help "Describe function"
+    :persistent-help "Toggle describe function"
     :nomark t
     :action '(("Describe function" . helm-describe-function)
               ("Find function" . helm-find-function)
@@ -611,7 +614,7 @@ Filename completion happen if string start after or between a double quote."
     :persistent-action (lambda (candidate)
                          (helm-elisp--persistent-help
                           candidate 'helm-describe-function))
-    :persistent-help "Describe class"
+    :persistent-help "Toggle describe class"
     :action '(("Describe function" . helm-describe-function)
               ("Find function" . helm-find-function)
               ("Info lookup" . helm-info-lookup-symbol))))
@@ -629,7 +632,7 @@ Filename completion happen if string start after or between a double quote."
     :persistent-action (lambda (candidate)
                          (helm-elisp--persistent-help
                           candidate 'helm-describe-function))
-    :persistent-help "Describe generic function"
+    :persistent-help "Toggle describe generic function"
     :action '(("Describe function" . helm-describe-function)
               ("Find function" . helm-find-function)
               ("Info lookup" . helm-info-lookup-symbol))))
@@ -674,29 +677,6 @@ Filename completion happen if string start after or between a double quote."
   ;; when exiting with the fallback source.
   (run-with-idle-timer 0.01 nil #'helm-info-lookup-symbol-1 candidate))
 
-(defun helm-elisp--persistent-help (candidate fun &optional name)
-  (let ((hbuf (get-buffer (help-buffer))))
-    (cond  ((helm-follow-mode-p)
-            (if name
-                (funcall fun candidate name)
-                (funcall fun candidate)))
-           ((or (and (helm-attr 'help-running-p)
-                     (string= candidate (helm-attr 'help-current-symbol))))
-            (progn
-              ;; When started from a help buffer,
-              ;; Don't kill this buffer as it is helm-current-buffer.
-              (unless (equal hbuf helm-current-buffer)
-                (kill-buffer hbuf)
-                (set-window-buffer (get-buffer-window hbuf)
-                                   helm-current-buffer))
-              (helm-attrset 'help-running-p nil)))
-           (t
-            (if name
-                (funcall fun candidate name)
-                (funcall fun candidate))
-            (helm-attrset 'help-running-p t)))
-    (helm-attrset 'help-current-symbol candidate)))
-
 ;;;###autoload
 (defun helm-apropos (default)
   "Preconfigured helm to describe commands, functions, variables and faces.
@@ -722,7 +702,7 @@ i.e the `symbol-name' of any existing symbol."
     :persistent-action 'helm-advice-persistent-action
     :nomark t
     :multiline t
-    :persistent-help "Describe function / C-u C-j: Toggle advice"))
+    :persistent-help "Toggle describe function / C-u C-j: Toggle advice"))
 
 (defun helm-advice-candidates ()
   (cl-loop for (fname) in ad-advised-functions
@@ -940,7 +920,7 @@ i.e the `symbol-name' of any existing symbol."
 (provide 'helm-elisp)
 
 ;; Local Variables:
-;; byte-compile-warnings: (not cl-functions obsolete)
+;; byte-compile-warnings: (not obsolete)
 ;; coding: utf-8
 ;; indent-tabs-mode: nil
 ;; End:
