@@ -315,6 +315,7 @@ You probably don't need to use this unless you know what you are doing."
 (defvar helm-grep-default-function 'helm-grep-init)
 (defvar helm-zgrep-recurse-flag nil)
 (defvar helm-grep-history nil)
+(defvar helm-grep-ag-history nil)
 (defvar helm-grep-last-targets nil)
 (defvar helm-grep-include-files nil)
 (defvar helm-grep-in-recurse nil)
@@ -485,6 +486,13 @@ It is intended to use as a let-bound variable, DON'T set this globaly.")
          ;; Use pipe only with grep, zgrep or git-grep.
          (process-connection-type (and (not zgrep) (helm-grep-use-ack-p)))
          (tramp-verbose helm-tramp-verbose)
+         (start-time (float-time))
+         (proc-name (if helm-grep-use-zgrep
+                        "Zgrep"
+                        (capitalize
+                         (if helm-grep-in-recurse
+                             (helm-grep-command t)
+                             (helm-grep-command)))))
          non-essential)
     ;; Start grep process.
     (helm-log "Starting Grep process in directory `%s'" default-directory)
@@ -492,7 +500,7 @@ It is intended to use as a let-bound variable, DON'T set this globaly.")
               (concat ">>> " (propertize cmd-line 'face 'helm-grep-cmd-line) "\n\n"))
     (prog1            ; This function should return the process first.
         (start-file-process-shell-command
-         "grep" helm-buffer cmd-line)
+         proc-name helm-buffer cmd-line)
       ;; Init sentinel.
       (set-process-sentinel
        (get-buffer-process helm-buffer)
@@ -503,49 +511,49 @@ It is intended to use as a let-bound variable, DON'T set this globaly.")
                (helm-process-deferred-sentinel-hook
                 process event (helm-default-directory)))
              (cond ((and noresult
-                         ;; [FIXME] This is a workaround for zgrep
+                         ;; This is a workaround for zgrep
                          ;; that exit with code 1
                          ;; after a certain amount of results.
-                         (not (with-helm-buffer helm-grep-use-zgrep)))
+                         (with-helm-buffer (helm-empty-buffer-p)))
                     (with-helm-buffer
                       (insert (concat "* Exit with code 1, no result found,"
                                       " command line was:\n\n "
                                       (propertize helm-grep-last-cmd-line
                                                   'face 'helm-grep-cmd-line)))
                       (setq mode-line-format
-                            '(" " mode-line-buffer-identification " "
+                            `(" " mode-line-buffer-identification " "
                               (:eval (format "L%s" (helm-candidate-number-at-point))) " "
                               (:eval (propertize
                                       (format
                                        "[%s process finished - (no results)] "
-                                       (if helm-grep-use-zgrep
-                                           "Zgrep"
-                                         (capitalize
-                                          (if helm-grep-in-recurse
-                                              (helm-grep-command t)
-                                            (helm-grep-command)))))
+                                       ,proc-name)
                                       'face 'helm-grep-finish))))))
-                   ((string= event "finished\n")
+                   ((or (string= event "finished\n")
+                        (and noresult
+                             ;; This is a workaround for zgrep
+                             ;; that exit with code 1
+                             ;; after a certain amount of results.
+                             (with-helm-buffer (not (helm-empty-buffer-p)))))
+                    (helm-log "%s process finished with %s results in %fs"
+                              proc-name
+                              (helm-get-candidate-number)
+                              (- (float-time) start-time))
                     (with-helm-window
                       (setq mode-line-format
-                            '(" " mode-line-buffer-identification " "
+                            `(" " mode-line-buffer-identification " "
                               (:eval (format "L%s" (helm-candidate-number-at-point))) " "
                               (:eval (propertize
                                       (format
-                                       "[%s process finished - (%s results)] "
-                                       (if helm-grep-use-zgrep
-                                           "Zgrep"
-                                         (capitalize
-                                          (if helm-grep-in-recurse
-                                              (helm-grep-command t)
-                                            (helm-grep-command))))
+                                       "[%s process finished in %.2fs - (%s results)] "
+                                       ,proc-name
+                                       ,(- (float-time) start-time)
                                        (helm-get-candidate-number))
                                       'face 'helm-grep-finish))))
                       (force-mode-line-update)))
                    ;; Catch error output in log.
                    (t (helm-log
                        "Error: %s %s"
-                       (if helm-grep-use-zgrep "Zgrep" "Grep")
+                       proc-name
                        (replace-regexp-in-string "\n" "" event))))))))))
 
 (defun helm-grep-collect-candidates ()
@@ -982,7 +990,7 @@ It is used actually to specify 'zgrep' or 'git'.
 When BACKEND 'zgrep' is used don't prompt for a choice
 in recurse, and ignore EXTS, search being made recursively on files matching
 `helm-zgrep-file-extension-regexp' only."
-  (when (and (helm-grep-use-ack-p)
+  (when (and (string-match-p "\\`ack" (helm-grep-command recurse backend))
              helm-ff-default-directory
              (file-remote-p helm-ff-default-directory))
     (error "Error: Remote operation not supported with ack-grep."))
@@ -1009,7 +1017,14 @@ in recurse, and ignore EXTS, search being made recursively on files matching
                      ;; ignore types and do not prompt for choice.
                      (string-match "%e" helm-grep-default-command)
                      (helm-grep-read-ack-type)))
-         (src-name (capitalize (helm-grep-command recurse backend))))
+         (src-name (capitalize (helm-grep-command recurse backend)))
+         (com (cond ((eq backend 'zgrep) helm-default-zgrep-command)
+                    ((eq backend 'git) helm-grep-git-grep-command)
+                    (recurse helm-grep-default-recurse-command)
+                    ;; When resuming, the local value of
+                    ;; `helm-grep-default-command' is used, only git-grep
+                    ;; should need this.
+                    (t helm-grep-default-command))))
     ;; When called as action from an other source e.g *-find-files
     ;; we have to kill action buffer.
     (when (get-buffer helm-action-buffer)
@@ -1027,19 +1042,12 @@ in recurse, and ignore EXTS, search being made recursively on files matching
      'helm-grep-include-files (or include-files types)
      'helm-grep-in-recurse recurse
      'helm-grep-use-zgrep (eq backend 'zgrep)
-     'helm-grep-default-command
-     (cond ((eq backend 'zgrep) helm-default-zgrep-command)
-           ((eq backend 'git) helm-grep-git-grep-command)
-           (recurse helm-grep-default-recurse-command)
-           ;; When resuming, the local value of
-           ;; `helm-grep-default-command' is used, only git-grep
-           ;; should need this.
-           (t helm-grep-default-command))
+     'helm-grep-default-command com
      'default-directory helm-ff-default-directory) ;; [1]
     ;; Setup the source.
     (set source (helm-make-source src-name 'helm-grep-class
                   :backend backend
-                  :pcre (if recurse ack-rec-p (helm-grep-use-ack-p))))
+                  :pcre (string-match-p "\\`ack" com)))
     (helm
      :sources source
      :buffer (format "*helm %s*" (helm-grep-command recurse backend))
@@ -1371,15 +1379,17 @@ if available with current AG version."
 (defun helm-grep-ag-init (directory &optional type)
   "Start AG process in DIRECTORY maybe searching only files of type TYPE."
   (let ((cmd-line (helm-grep-ag-prepare-cmd-line
-                   helm-pattern directory type)))
+                   helm-pattern directory type))
+        (start-time (float-time))
+        (proc-name (helm-grep--ag-command)))
     (set (make-local-variable 'helm-grep-last-cmd-line) cmd-line)
     (helm-log "Starting %s process in directory `%s'"
-              (helm-grep--ag-command) directory)
+              proc-name directory)
     (helm-log "Command line used was:\n\n%s"
               (concat ">>> " cmd-line "\n\n"))
     (prog1
         (start-process-shell-command
-         "ag" helm-buffer cmd-line)
+         proc-name helm-buffer cmd-line)
       (set-process-sentinel
        (get-buffer-process helm-buffer)
        (lambda (process event)
@@ -1397,23 +1407,28 @@ if available with current AG version."
                             (:eval (propertize
                                     (format
                                      "[%s process finished - (no results)] "
-                                     (upcase (helm-grep--ag-command)))
+                                     (upcase proc-name))
                                     'face 'helm-grep-finish))))))
                  ((string= event "finished\n")
+                  (helm-log "%s process finished with %s results in %fs"
+                              proc-name
+                              (helm-get-candidate-number)
+                              (- (float-time) start-time))
                   (with-helm-window
                     (setq mode-line-format
-                          '(" " mode-line-buffer-identification " "
+                          `(" " mode-line-buffer-identification " "
                             (:eval (format "L%s" (helm-candidate-number-at-point))) " "
                             (:eval (propertize
                                     (format
-                                     "[%s process finished - (%s results)] "
-                                     (upcase (helm-grep--ag-command))
+                                     "[%s process finished in %.2fs - (%s results)] "
+                                     ,(upcase proc-name)
+                                     ,(- (float-time) start-time)
                                      (helm-get-candidate-number))
                                     'face 'helm-grep-finish))))
                     (force-mode-line-update)))
                  (t (helm-log
                      "Error: %s %s"
-                     (helm-grep--ag-command)
+                     proc-name
                      (replace-regexp-in-string "\n" "" event))))))))))
 
 (defclass helm-grep-ag-class (helm-source-async)
@@ -1422,9 +1437,11 @@ if available with current AG version."
          :documentation
          "  Backend is using pcre regexp engine when non--nil.")
    (keymap :initform helm-grep-map)
+   (history :initform 'helm-grep-ag-history)
    (help-message :initform 'helm-grep-help-message)
    (filter-one-by-one :initform 'helm-grep-filter-one-by-one)
    (persistent-action :initform 'helm-grep-persistent-action)
+   (persistent-help :initform "Jump to line (`C-u' Record in mark ring)")
    (candidate-number-limit :initform 99999)
    (requires-pattern :initform 2)
    (nomark :initform t)
@@ -1450,6 +1467,7 @@ if available with current AG version."
           (lambda () (helm-grep-ag-init directory type))))
   (helm :sources 'helm-source-grep-ag
         :keymap helm-grep-map
+        :history 'helm-grep-ag-history
         :truncate-lines helm-grep-truncate-lines
         :buffer (format "*helm %s*" (helm-grep--ag-command))))
 
@@ -1525,7 +1543,7 @@ With a prefix arg ARG git-grep the whole repository."
 (provide 'helm-grep)
 
 ;; Local Variables:
-;; byte-compile-warnings: (not cl-functions obsolete)
+;; byte-compile-warnings: (not obsolete)
 ;; coding: utf-8
 ;; indent-tabs-mode: nil
 ;; End:
