@@ -75,7 +75,7 @@ If nil or zero (disabled), don't truncate candidate, show all."
     :candidates #'helm-kill-ring-candidates
     :filtered-candidate-transformer #'helm-kill-ring-transformer
     :action 'helm-kill-ring-actions
-    :persistent-action (lambda (_candidate) (ignore))
+    :persistent-action 'ignore
     :persistent-help "DoNothing"
     :keymap helm-kill-ring-map
     :migemo t
@@ -461,7 +461,7 @@ This command is useful when used with persistent action."
 (provide 'helm-ring)
 
 ;; Local Variables:
-;; byte-compile-warnings: (not cl-functions obsolete)
+;; byte-compile-warnings: (not obsolete)
 ;; coding: utf-8
 ;; indent-tabs-mode: nil
 ;; End:
